#----------------------------------------------------------
#Function for the event procedure
#----------------------------------------------------------
use mwt;

sub btnop {
	my ($object) = @_;
	#do something...
	$object->setProperty("labelString","hello!");
}
